import sys
import requests
import json
import bs4

def traverse(element):
    children = element.findChildren(recursive=False)
    if not len(children):
        element.attrs['text'] = element.text
        return element.attrs if len(element.attrs) > 1 else element.text
    else:
        structure = element.attrs;
        for child in children:
            structure[child.name] = traverse(child)
        return structure

def lurk(urls, selector):
    urls = urls if type(urls) is list else [ urls ]
    output = []
    for url in urls:
        request = requests.get(url)
        dom = bs4.BeautifulSoup(request.content, 'html.parser')
        for element in dom.select(selector):
            output.append(traverse(element))
    return output

def main():
    if len(sys.argv) != 3:
        print 'Usage: lurk <url> <selector> [> <output file>]'
        sys.exit(0)
    print json.dumps(lurk(sys.argv[1], sys.argv[2]))



from setuptools import setup, find_packages
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='lurk',
    version='0.1.3',
    description='Extract html from one or multiple urls',
    long_description=long_description,
    url='https://github.com/mateogianolio/lurk',
    author='Mateo Gianolio',
    author_email='gianoliomateo@gmail.com',
    license='MIT',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Libraries',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
    ],
    keywords='lurk lurker scrape scraper scraping webscrape crawl crawler crawling',
    packages=find_packages(exclude=['contrib', 'docs', 'tests*']),
    install_requires=['beautifulsoup4'],
    entry_points={
        'console_scripts': [
            'lurk=module:main',
        ],
    }
)
